% Pattern Recognition Library (PRlib)
%==========================================================================
% KV-Lib Toolbox for MATLAB 6.x 
% Version 2.5, Dec 2007
%==========================================================================
%
% This toolbox is based on generic Image Manipulation 
% and Pattern Recognition functions
% 
% For more details, please contact:
%  Dr K. Veropoulos, k_veropoulos@freemail.gr
%
%--------------------------------------------------------------------------
% Pattern Recognition Library (PRlib) for Classification:
%--------------------------------------------------------------------------
%
%  cca          - computes the canonical correlation function coefficients
%                 for two given variable sets 'X' and 'Y'.
%
%  KCCA         - function to solve the single eigenproblem of Kernel CCA.
%
%  kcca2        - applies a Kernel CCA transformation on a kernel matrix
%                 using the specified (pre-calculated) eigenvectors and
%                 eigenvalues of a system.
%
%  kernel_mat   - computes the kernel matrix of two given variable sets
%                 'X1' and 'X2'.
%
%  knn          - k-Nearest Neighbor Classifier.
%
%  SV_knn       - k-Nearest Neighbor Classifier to support vectors of a
%                 training set.
%
%  lda          - Linear Discriminant Analysis.
%
%  mindist      - Minimum Distance Classifier using the Euclidean Distance
%                 measure.
%
%  Normalize    - normalize all the samples to make their energy is 1.
%
%  Scale        - scale all the samples to a range, such as [-1 1].
%
%  kNormalize   - normalizes and centers a kernel matrix.
%
%  pcas         - computes the principal components (sorted by largest
%                 magnitude eigenvalues) of a given matrix 'X'. It also
%                 returns the 'pinfo' Significant Principal Components
%                 (i.e. returns the number of principal compoments
%                 containing 'pinfo' or higher information energy of the
%                 overall data).
%
%  kpca1        - performs Kernel PCA on a kernel matrix as a single
%                 eigenvalue problem using the specified number of largest
%                 magnitude principal components.
%
%  kpca2        - applies a Kernel PCA transformation on a kernel matrix
%                 using the specified (pre-calculated) eigenvectors and
%                 eigenvalues of a system.
%
%  PCAtk        - (PCA Toolkit) provides a step-by-step GUI process that
%                 makes use of pcas for computing & saving into files the
%                 eigen- vectors & values from one or more data files. It
%                 can also be used for projecting multiple data files to
%                 the saved eigenspace. (The data files should be generated
%                 using IDBMS or have the IDBMS data structure).
%
%  svmtrain     - slightly modified version Chih-Chung Chang's Support Vector 
%                 Machine training function from LIBSVM (v2.81).
%
%  svmpredict   - Chih-Chung Chang's Support Vector Machine prediction
%                 function as provided in LIBSVM (v2.81).
%
%  csvm_opt     - performs an optimized C-SVM training using 5-fold
%                 cross-validation and hyperparameter grid-search.
%
%  csvm_fs      - performs optimized C-SVM training (hyperparameter
%                 grid-search) with feature selection. 
%
%  percentres   - converts a confusion matrix between actual and expected
%                 target to percentage rates. 
%
%  res2str      - puts classification results into a character array
%                 (string).
%
%  results      - computes the confusion matrix between actual and expected
%                 targets.
%  _                                                                     _
% |                                                                       |
% | For more details on both svmtrain and svmpredict please visit the     |
% | libSVM site at <http://www.csie.ntu.edu.tw/~cjlin/libsvm/>            |
% |_                                                                     _|
%
%--------------------------------------------------------------------------
% Pattern Recognition Library (PRlib) for Verification/Identification:
%--------------------------------------------------------------------------
%
%  calcCMCs     - calculates Cumulative Match Curves (CMCs) for a given
%                 gallery set 'G' and a query set 'Q'. Makes use of the
%                 RankTable function (see description below).
%
%  calcROCs     - calculates Receiver Operating Characteristic Curves
%                 (ROCs) for a given gallery set 'G' and a query set 'Q'.
%                 Makes use of the PerfTable function (see description
%                 below).
%
%  find_avgerr  - computes error statistics from 'GlobalAcc' and 'ClassAcc'
%                 results as outputed from the calcROCs function.
%
%  PerfTable	- returns the ROC curve, confusion matrix anf FID table
%                 that result from after a matching process (the FID table
%                 is a table that contains the results of each comparison
%                 that took place and the type of error that occured; type
%                 'PerfTable' with no input arguments for details).
%
%  RankTable    - returns the CMC curve as computed after a matching
%                 process has been completed.
%
%
%--------------------------------------------------------------------------
% PRlib for Verification: USAGE EXAMPLE CODE
%--------------------------------------------------------------------------
%
% 		D=mahalanobis(G,Q); % distance matrix between the gallery set 'G' and the query set 'Q'.
% 		
% 		fprintf('Please wait while calculating the ROC curves...\n   Calling CalcROCs()\n');
% 		[GlobalAcc, ClassAcc, ClassROC, ClassConfM] = CalcROCs(G, Q, Glabels, Qlabels, Gids, Qids, D);
% 		fprintf('   CalcROCs() finished!\n');
% 		fprintf('   Saving ROC curves results to ''CalcROCs_results.mat''...\n');
% 		resfile='ROCs.mat';
% 		save(resfile,'ClassROC','ClassConfM','GlobalAcc','ClassAcc');
% 		
% 		fprintf('Please wait while calculating the CMC plots...\n   Calling CalcCMCs()\n');
% 		[GlobalCMC, ClassCMC] = CalcCMCs(G, Q, Glabels, Qlabels, Gids, Qids, D);
% 		fprintf('   CalcCMCs() finished!\n');
% 		fprintf('   Saving CMC plots to ''CalcCMCs_results.mat''...\n');
% 		resfile='CMCs.mat';
% 		save(resfile,'GlobalCMC','ClassCMC');
% 		
% 		
% 		fprintf('----------------------------------------------------------------------\n');
% 		find_avgerr(GlobalAcc, ClassAcc, Classes);
% 		fprintf('----------------------------------------------------------------------\n');
% 		fprintf('---------------------------------------------\n');
% 		fprintf('Process completed!\n');
% 		fprintf('---------------------------------------------\n');
% 		
%
%
%==========================================================================
% Author: 
% K. Veropoulos (verop@unr.edu, k_veropoulos@freemail.gr)
% for the Computer Science & Engineering Dept. of the 
% University of Nevada Reno (UNR).
%
