function model = svmtrain(training_label_vector, training_instance_matrix, libsvm_options)
% SVMTRAIN: SVM Training
% 
% Usage: model = svmtrain(training_label_vector, training_instance_matrix, libsvm_options);
% 
% INPUT
%   training_label_vector       An m by 1 vector of training labels.
%   training_instance_matrix    An m by n matrix of m training instances with n features.
%                               It can be dense or sparse.
%   libsvm_options              A string of training options
% 		-s svm_type : set type of SVM (default 0)
% 			0 -- C-SVC
% 			1 -- nu-SVC
% 			2 -- one-class SVM
% 			3 -- epsilon-SVR
% 			4 -- nu-SVR
% 		-t kernel_type : set type of kernel function (default 2)
% 			0 -- linear: u'*v
% 			1 -- polynomial: (gamma*u'*v + coef0)^degree
% 			2 -- radial basis function: exp(-gamma*|u-v|^2)
% 			3 -- sigmoid: tanh(gamma*u'*v + coef0)
% 		-d degree : set degree in kernel function (default 3)
% 		-g gamma : set gamma in kernel function (default 1/k)
% 		-r coef0 : set coef0 in kernel function (default 0)
% 		-c cost : set the parameter C of C-SVC, epsilon-SVR, and nu-SVR (default 1)
% 		-n nu : set the parameter nu of nu-SVC, one-class SVM, and nu-SVR (default 0.5)
% 		-p epsilon : set the epsilon in loss function of epsilon-SVR (default 0.1)
% 		-m cachesize : set cache memory size in MB (default 40)
% 		-e epsilon : set tolerance of termination criterion (default 0.001)
% 		-h shrinking: whether to use the shrinking heuristics, 0 or 1 (default 1)
% 		-b probability_estimates: whether to train a SVC or SVR model for probability 
%           estimates, 0 or 1 (default 0)
% 		-wi weight: set the parameter C of class i to weight*C, for C-SVC (default 1)
% 		-v n: n-fold cross validation mode; the returned model is just a scalar
%           (cross-validation accuracy for classification and mean-squared error for 
%           regression)
% 
% OUTPUT
%   model                       data structure containing the following fields:
% 		model.Parameters	 array (size 11) containing the parameters of the predictor.
%                            Specifically:
% 			  Parameters(1)	 SVM type
% 			  Parameters(2)  kernel type
% 			  Parameters(3)	 degree in kernel function
% 			  Parameters(4)	 gamma in kernel function
% 			  Parameters(5)	 coefficient in kernel function
% 			  Parameters(6)	 cost C of C-SVC, epsilon-SVR, and nu-SVR
% 			  Parameters(7)	 parameter nu of nu-SVC, one-class SVM, and nu-SVR
% 			  Parameters(8)	 tolerance of termination criterion
% 			  Parameters(9)	 cache memory size in MB
% 			  Parameters(10) the epsilon in loss function of epsilon-SVR
% 			  Parameters(11) flag for the shrinking heuristics
% 		model.nr_class		 number of classes; = 2 for regression/one-class svm
% 		model.totalSV		 number of support vectors used
% 		model.rho			 bias of the decision function(s)
% 		model.Label			 label of each class; empty for regression/one-class SVM
% 		model.ProbA			 pairwise probability information; empty if -b 0 or in one-class SVM
% 		model.ProbB			 pairwise probability information; empty if -b 0 or in one-class SVM
% 		model.nSV			 number of SVs for each class; empty for regression/one-class SVM
% 		model.sv_coef		 coefficients for SVs in decision functions
% 		model.SVs			 support vectors
% 		model.SVidx			 support vectors indices
% 
% See also: SVMPREDICT, CSVM_OPT, CSVM_FS, PARSGRID, FEATSELS
% 
% LIBSVM written by Chih-Chung Chang and Chih-Jen Lin (http://www.csie.ntu.edu.tw/~cjlin/libsvm)
% MATLAB Interface written by Jun-Cheng Chen, Kuan-Jen Peng, Chih-Yuan Yang and Chih-Huai Cheng
% 
% modified by K. Veropoulos for KV_LIB
% (kvero@dri.edu or k_veropoulos@freemail.gr)
% 
